@@ -198,6 +198,7 @@ class Browser:
             render as render_rec_daily_songs
         from feeluown.gui.pages.my_fav import render as render_my_fav
         from feeluown.gui.pages.homepage import render as render_homepage
+        from feeluown.gui.pages.toplist import render as render_toplist
 
         model_prefix = f'{MODEL_PAGE_PREFIX}<provider>'
 
@@ -218,6 +219,7 @@ class Browser:
             ('/homepage', render_homepage),
             ('/rec/daily_songs', render_rec_daily_songs),
             ('/my_fav', render_my_fav),
+            ('/toplist', render_toplist),
         ]
         for url, renderer in urlpatterns:
             self.route(url)(renderer)
